@@ -85,7 +85,7 @@ class ClaessonJaved(_LoadAggregation):
         ----------
         g_d : array
             Matrix of **dimensional** thermal response factors for temporal
-            superposition (:math:`g/(2 \pi k_s)`).
+            superposition (:math:`g/(2 \\pi k_s)`).
             The expected size is (nSources, nSources, Nt), where Nt is the
             number of time values at which the thermal response factors are
             required. The time values are returned by
@@ -98,8 +98,7 @@ class ClaessonJaved(_LoadAggregation):
         # Build matrix of thermal response factor increments
         self.dg = np.zeros_like(g_d)
         self.dg[:,:,0] = g_d[:,:,0]
-        for i in range(1, len(self._time)):
-            self.dg[:,:,i] = g_d[:,:,i] - g_d[:,:,i-1]
+        self.dg[:,:,1:] = g_d[:,:,1:] - g_d[:,:,:-1]
 
     def next_time_step(self, time):
         """
@@ -111,7 +110,7 @@ class ClaessonJaved(_LoadAggregation):
             Current value of time (in seconds).
 
         """
-        self.Q = self.Q @ self.A
+        self.q_b = self.q_b @ self.A
 
     def get_thermal_response_factor_increment(self):
         """
@@ -122,7 +121,7 @@ class ClaessonJaved(_LoadAggregation):
         dg : array
             Array of **dimensional** thermal response factor increments used
             for temporal superposition 
-            (:math:`g(t_{i+1})/(2 \pi k_s) - g(t_{i})/(2 \pi k_s)`),
+            (:math:`g(t_{i+1})/(2 \\pi k_s) - g(t_{i})/(2 \\pi k_s)`),
             in correspondance with the intialized values of the thermal
             response factors in 
             :func:`~load_aggregation.ClaessonJaved.initialize`.
@@ -150,18 +149,18 @@ class ClaessonJaved(_LoadAggregation):
         """
         return self._time
 
-    def set_current_load(self, Q):
+    def set_current_load(self, q_b):
         """
         Set the load at the current time step.
 
         Parameters
         ----------
-        Q : float or array
+        q_b : float or array
             Current value of heat extraction rates per unit borehole length
             (in watts per meter).
 
         """
-        self.Q[:,0] = Q
+        self.q_b[:,0] = q_b
 
     def temporal_superposition(self):
         """
@@ -178,16 +177,16 @@ class ClaessonJaved(_LoadAggregation):
            *pygfunction* assumes positive values for heat
            **extraction** and for borehole wall temperature **drops**. The
            borehole wall temperature are thus given by :
-           :math:`T_b = T_g - \Delta T_b`.
+           :math:`T_b = T_g - \\Delta T_b`.
 
         """
         # Use numpy.einsum for spatial and temporal superposition
         # This is equivalent to :
-        #    deltaT = self.dg[:,:,0].dot(self.Q[:,0])
+        #    deltaT = self.dg[:,:,0].dot(self.q_b[:,0])
         #    for i in range(1, len(self._time)):
-        #        deltaT += (self.dg[:,:,i]).dot(self.Q[:,i])
+        #        deltaT += (self.dg[:,:,i]).dot(self.q_b[:,i])
 
-        deltaT = np.einsum('ijk,jk', self.dg, self.Q)
+        deltaT = np.einsum('ijk,jk', self.dg, self.q_b)
         return deltaT
 
     def _build_cells(self, dt, tmax, nSources, cells_per_level):
@@ -213,7 +212,7 @@ class ClaessonJaved(_LoadAggregation):
                                  (self._time[1:] - self._time[:-1])/dt))
         # Initialize aggregated loads
         nt = len(self._time)
-        self.Q = np.zeros((nSources, nt))
+        self.q_b = np.zeros((nSources, nt))
         # Matrix for time shifting of aggregated loads. For two consecutive
         # time steps : Q(t+1) = Q(t) @ A
         self.A = (1. - 1./self._width) * np.eye(nt) \
@@ -273,7 +272,7 @@ class MLAA(_LoadAggregation):
         ----------
         g_d : array
             Matrix of **dimensional** thermal response factors for temporal
-            superposition (:math:`g/(2 \pi k_s)`).
+            superposition (:math:`g/(2 \\pi k_s)`).
             The expected size is (nSources, nSources, Nt), where Nt is the
             number of time values at which the thermal response factors are
             required. The time values are returned by
@@ -305,7 +304,7 @@ class MLAA(_LoadAggregation):
         else:
             self._n0 = self.N0
         # The non-aggregated loads are the n0 latest loads
-        self.Q0[:, -self._n0:] = self.Q[:, self._nt-self._n0:self._nt]
+        self.Q0[:, -self._n0:] = self.q_b[:, self._nt-self._n0:self._nt]
 
         # Once the number of time steps reaches (N0 + N1), the first load
         # aggregation cell is created
@@ -314,7 +313,7 @@ class MLAA(_LoadAggregation):
             # Averaged loads in first cell
             start = self._nt - (self._n0 + self._n1)
             end = self._nt - self._n0
-            self.Q1 = np.mean(self.Q[:, start:end], axis=1)
+            self.Q1 = np.mean(self.q_b[:, start:end], axis=1)
         else:
             self._n1 = 0
 
@@ -325,7 +324,7 @@ class MLAA(_LoadAggregation):
             # Averaged loads in second cell
             start = self._nt - (self._n0 + self._n1 + self._n2)
             end = self._nt - (self._n0 + self._n1)
-            self.Q2 = np.mean(self.Q[:, start:end], axis=1)
+            self.Q2 = np.mean(self.q_b[:, start:end], axis=1)
         else:
             self._n2 = 0
 
@@ -336,7 +335,7 @@ class MLAA(_LoadAggregation):
             # Averaged loads in third cell
             start = self._nt - (self._n0 + self._n1 + self._n2 + self._n3)
             end = self._nt - (self._n0 + self._n1 + self._n2)
-            self.Q3 = np.mean(self.Q[:, start:end], axis=1)
+            self.Q3 = np.mean(self.q_b[:, start:end], axis=1)
         else:
             self._n3 = 0
 
@@ -347,7 +346,7 @@ class MLAA(_LoadAggregation):
         if self._n4 > 0:
             start = 0
             end = self._n4
-            self.Q4 = np.mean(self.Q[:, start:end], axis=1)
+            self.Q4 = np.mean(self.q_b[:, start:end], axis=1)
 
     def get_times_for_simulation(self):
         """
@@ -363,19 +362,19 @@ class MLAA(_LoadAggregation):
         """
         return np.array([(i+1)*self.dt for i in range(self.Nt)])
 
-    def set_current_load(self, Q):
+    def set_current_load(self, q_b):
         """
         Set the load at the current time step.
 
         Parameters
         ----------
-        Q : array
+        q_b : array
             Current value of heat extraction rates per unit borehole length
             (in watts per meter).
 
         """
-        self.Q[:,self._nt-1] = Q
-        self.Q0[:,-1] = Q
+        self.q_b[:,self._nt-1] = q_b
+        self.Q0[:,-1] = q_b
 
     def temporal_superposition(self):
         """
@@ -392,7 +391,7 @@ class MLAA(_LoadAggregation):
            *pygfunction* assumes positive values for heat
            **extraction** and for borehole wall temperature **drops**. The
            borehole wall temperature are thus given by :
-           :math:`T_b = T_g - \Delta T_b`.
+           :math:`T_b = T_g - \\Delta T_b`.
 
         """
         # Non-aggregated loads
@@ -456,7 +455,7 @@ class MLAA(_LoadAggregation):
         self.N2 = N2
         self.N3 = N3
         # Initialize non-aggregated loads
-        self.Q = np.zeros((nSources, self.Nt))
+        self.q_b = np.zeros((nSources, self.Nt))
         self.Q0 = np.zeros((nSources, self.N0))
         # Initialize aggregated loads
         self.Q1 = np.zeros(nSources)
@@ -525,7 +524,7 @@ class Liu(_LoadAggregation):
         ----------
         g_d : array
             Matrix of **dimensional** thermal response factors for temporal
-            superposition (:math:`g/(2 \pi k_s)`).
+            superposition (:math:`g/(2 \\pi k_s)`).
             The expected size is (nSources, nSources, Nt), where Nt is the
             number of time values at which the thermal response factors are
             required. The time values are returned by
@@ -611,18 +610,18 @@ class Liu(_LoadAggregation):
         """
         return np.array([(i+1)*self.dt for i in range(self.Nt)])
 
-    def set_current_load(self, Q):
+    def set_current_load(self, q_b):
         """
         Set the load at the current time step.
 
         Parameters
         ----------
-        Q : array
+        q_b : array
             Current value of heat extraction rates per unit borehole length
             (in watts per meter).
 
         """
-        self.Q0[:,0] = Q
+        self.Q0[:,0] = q_b
 
     def temporal_superposition(self):
         """
@@ -639,7 +638,7 @@ class Liu(_LoadAggregation):
            *pygfunction* assumes positive values for heat
            **extraction** and for borehole wall temperature **drops**. The
            borehole wall temperature are thus given by :
-           :math:`T_b = T_g - \Delta T_b`.
+           :math:`T_b = T_g - \\Delta T_b`.
 
         """
         deltaT = 0.
